@@ -15,6 +15,20 @@ import matplotlib.transforms as mtransforms
 from matplotlib.spines import Spine
 
 
+def _apply_theta_transforms_warn():
+    _api.warn_deprecated(
+                "3.9",
+                message=(
+                    "Passing `apply_theta_transforms=True` (the default) "
+                    "is deprecated since Matplotlib %(since)s. "
+                    "Support for this will be removed in Matplotlib in %(removal)s. "
+                    "To prevent this warning, set `apply_theta_transforms=False`, "
+                    "and make sure to shift theta values before being passed to "
+                    "this transform."
+                )
+            )
+
+
 class PolarTransform(mtransforms.Transform):
     r"""
     The base polar transform.
@@ -34,8 +48,8 @@ class PolarTransform(mtransforms.Transform):
 
     input_dims = output_dims = 2
 
-    def __init__(self, axis=None, use_rmin=True,
-                 _apply_theta_transforms=True, *, scale_transform=None):
+    def __init__(self, axis=None, use_rmin=True, *,
+                 apply_theta_transforms=True, scale_transform=None):
         """
         Parameters
         ----------
@@ -50,20 +64,21 @@ class PolarTransform(mtransforms.Transform):
         super().__init__()
         self._axis = axis
         self._use_rmin = use_rmin
-        self._apply_theta_transforms = _apply_theta_transforms
+        self._apply_theta_transforms = apply_theta_transforms
         self._scale_transform = scale_transform
+        if apply_theta_transforms:
+            _apply_theta_transforms_warn()
 
     __str__ = mtransforms._make_str_method(
         "_axis",
         use_rmin="_use_rmin",
-        _apply_theta_transforms="_apply_theta_transforms")
+        apply_theta_transforms="_apply_theta_transforms")
 
     def _get_rorigin(self):
         # Get lower r limit after being scaled by the radial scale transform
         return self._scale_transform.transform(
             (0, self._axis.get_rorigin()))[1]
 
-    @_api.rename_parameter("3.8", "tr", "values")
     def transform_non_affine(self, values):
         # docstring inherited
         theta, r = np.transpose(values)
@@ -133,15 +148,17 @@ class PolarTransform(mtransforms.Transform):
 
     def inverted(self):
         # docstring inherited
-        return PolarAxes.InvertedPolarTransform(self._axis, self._use_rmin,
-                                                self._apply_theta_transforms)
+        return PolarAxes.InvertedPolarTransform(
+            self._axis, self._use_rmin,
+            apply_theta_transforms=self._apply_theta_transforms
+        )
 
 
 class PolarAffine(mtransforms.Affine2DBase):
     r"""
     The affine part of the polar projection.
 
-    Scales the output so that maximum radius rests on the edge of the axes
+    Scales the output so that maximum radius rests on the edge of the Axes
     circle and the origin is mapped to (0.5, 0.5). The transform applied is
     the same to x and y components and given by:
 
@@ -193,7 +210,7 @@ class InvertedPolarTransform(mtransforms.Transform):
     input_dims = output_dims = 2
 
     def __init__(self, axis=None, use_rmin=True,
-                 _apply_theta_transforms=True):
+                 *, apply_theta_transforms=True):
         """
         Parameters
         ----------
@@ -201,21 +218,22 @@ class InvertedPolarTransform(mtransforms.Transform):
             Axis associated with this transform. This is used to get the
             minimum radial limit.
         use_rmin : `bool`, optional
-            If ``True`` add the minimum radial axis limit after
+            If ``True``, add the minimum radial axis limit after
             transforming from Cartesian coordinates. *axis* must also be
             specified for this to take effect.
         """
         super().__init__()
         self._axis = axis
         self._use_rmin = use_rmin
-        self._apply_theta_transforms = _apply_theta_transforms
+        self._apply_theta_transforms = apply_theta_transforms
+        if apply_theta_transforms:
+            _apply_theta_transforms_warn()
 
     __str__ = mtransforms._make_str_method(
         "_axis",
         use_rmin="_use_rmin",
-        _apply_theta_transforms="_apply_theta_transforms")
+        apply_theta_transforms="_apply_theta_transforms")
 
-    @_api.rename_parameter("3.8", "xy", "values")
     def transform_non_affine(self, values):
         # docstring inherited
         x, y = values.T
@@ -234,8 +252,10 @@ class InvertedPolarTransform(mtransforms.Transform):
 
     def inverted(self):
         # docstring inherited
-        return PolarAxes.PolarTransform(self._axis, self._use_rmin,
-                                        self._apply_theta_transforms)
+        return PolarAxes.PolarTransform(
+            self._axis, self._use_rmin,
+            apply_theta_transforms=self._apply_theta_transforms
+        )
 
 
 class ThetaFormatter(mticker.Formatter):
@@ -248,11 +268,7 @@ class ThetaFormatter(mticker.Formatter):
         vmin, vmax = self.axis.get_view_interval()
         d = np.rad2deg(abs(vmax - vmin))
         digits = max(-int(np.log10(d) - 1.5), 0)
-        # Use Unicode rather than mathtext with \circ, so that it will work
-        # correctly with any arbitrary font (assuming it has a degree sign),
-        # whereas $5\circ$ will only work correctly with one of the supported
-        # math fonts (Computer Modern and STIX).
-        return f"{np.rad2deg(x):0.{digits:d}f}\N{DEGREE SIGN}"
+        return f"{np.rad2deg(x):0.{digits}f}\N{DEGREE SIGN}"
 
 
 class _AxisWrapper:
@@ -323,9 +339,9 @@ class ThetaTick(maxis.XTick):
 
     def __init__(self, axes, *args, **kwargs):
         self._text1_translate = mtransforms.ScaledTranslation(
-            0, 0, axes.figure.dpi_scale_trans)
+            0, 0, axes.get_figure(root=False).dpi_scale_trans)
         self._text2_translate = mtransforms.ScaledTranslation(
-            0, 0, axes.figure.dpi_scale_trans)
+            0, 0, axes.get_figure(root=False).dpi_scale_trans)
         super().__init__(axes, *args, **kwargs)
         self.label1.set(
             rotation_mode='anchor',
@@ -504,7 +520,7 @@ class _ThetaShift(mtransforms.ScaledTranslation):
     Parameters
     ----------
     axes : `~matplotlib.axes.Axes`
-        The owning axes; used to determine limits.
+        The owning Axes; used to determine limits.
     pad : float
         The padding to apply, in points.
     mode : {'min', 'max', 'rlabel'}
@@ -512,7 +528,7 @@ class _ThetaShift(mtransforms.ScaledTranslation):
         of the axes, or using the rlabel position (``'rlabel'``).
     """
     def __init__(self, axes, pad, mode):
-        super().__init__(pad, pad, axes.figure.dpi_scale_trans)
+        super().__init__(pad, pad, axes.get_figure(root=False).dpi_scale_trans)
         self.set_children(axes._realViewLim)
         self.axes = axes
         self.mode = mode
@@ -524,24 +540,16 @@ class _ThetaShift(mtransforms.ScaledTranslation):
         if self._invalid:
             if self.mode == 'rlabel':
                 angle = (
-                    np.deg2rad(self.axes.get_rlabel_position()) *
-                    self.axes.get_theta_direction() +
-                    self.axes.get_theta_offset()
+                    np.deg2rad(self.axes.get_rlabel_position()
+                               * self.axes.get_theta_direction())
+                    + self.axes.get_theta_offset()
+                    - np.pi / 2
                 )
-            else:
-                if self.mode == 'min':
-                    angle = self.axes._realViewLim.xmin
-                elif self.mode == 'max':
-                    angle = self.axes._realViewLim.xmax
-
-            if self.mode in ('rlabel', 'min'):
-                padx = np.cos(angle - np.pi / 2)
-                pady = np.sin(angle - np.pi / 2)
-            else:
-                padx = np.cos(angle + np.pi / 2)
-                pady = np.sin(angle + np.pi / 2)
-
-            self._t = (self.pad * padx / 72, self.pad * pady / 72)
+            elif self.mode == 'min':
+                angle = self.axes._realViewLim.xmin - np.pi / 2
+            elif self.mode == 'max':
+                angle = self.axes._realViewLim.xmax + np.pi / 2
+            self._t = (self.pad * np.cos(angle) / 72, self.pad * np.sin(angle) / 72)
         return super().get_matrix()
 
 
@@ -747,7 +755,7 @@ def _is_full_circle_rad(thetamin, thetamax):
 
 class _WedgeBbox(mtransforms.Bbox):
     """
-    Transform (theta, r) wedge Bbox into axes bounding box.
+    Transform (theta, r) wedge Bbox into Axes bounding box.
 
     Parameters
     ----------
@@ -887,7 +895,7 @@ class PolarAxes(Axes):
         # data.  This one is aware of rmin
         self.transProjection = self.PolarTransform(
             self,
-            _apply_theta_transforms=False,
+            apply_theta_transforms=False,
             scale_transform=self.transScale
         )
         # Add dependency on rorigin.
@@ -1437,12 +1445,25 @@ class PolarAxes(Axes):
                     cbook._g_sig_digits(value, delta))
             return f"{value:-{opt}.{prec}{fmt}}"
 
-        return ('\N{GREEK SMALL LETTER THETA}={}\N{GREEK SMALL LETTER PI} '
-                '({}\N{DEGREE SIGN}), r={}').format(
+        # In case fmt_xdata was not specified, resort to default
+
+        if self.fmt_ydata is None:
+            r_label = format_sig(r, delta_r, "#", "g")
+        else:
+            r_label = self.format_ydata(r)
+
+        if self.fmt_xdata is None:
+            return ('\N{GREEK SMALL LETTER THETA}={}\N{GREEK SMALL LETTER PI} '
+                    '({}\N{DEGREE SIGN}), r={}').format(
                     format_sig(theta_halfturns, delta_t_halfturns, "", "f"),
                     format_sig(theta_degrees, delta_t_degrees, "", "f"),
-                    format_sig(r, delta_r, "#", "g"),
+                    r_label
                 )
+        else:
+            return '\N{GREEK SMALL LETTER THETA}={}, r={}'.format(
+                        self.format_xdata(theta),
+                        r_label
+                        )
 
     def get_data_ratio(self):
         """
