@@ -1,9 +1,10 @@
+import numpy as np
 import matplotlib.pyplot as plt
 
 
 def test_stem_remove():
     ax = plt.gca()
-    st = ax.stem([1, 2], [1, 2], use_line_collection=True)
+    st = ax.stem([1, 2], [1, 2])
     st.remove()
 
 
@@ -28,3 +29,9 @@ def test_errorbar_remove():
 
     eb = ax.errorbar([1], [1], fmt='none')
     eb.remove()
+
+
+def test_nonstring_label():
+    # Test for #26824
+    plt.bar(np.arange(10), np.random.rand(10), label=1)
+    plt.legend()
