@@ -3,10 +3,10 @@
 List of named colors
 ====================
 
-This plots a list of the named colors supported in matplotlib.
+This plots a list of the named colors supported by Matplotlib.
 For more information on colors in matplotlib see
 
-* the :doc:`/tutorials/colors/colors` tutorial;
+* the :ref:`colors_def` tutorial;
 * the `matplotlib.colors` API;
 * the :doc:`/gallery/color/color_demo`.
 
@@ -19,9 +19,10 @@ on some common color categories.
 
 import math
 
-from matplotlib.patches import Rectangle
 import matplotlib.pyplot as plt
+
 import matplotlib.colors as mcolors
+from matplotlib.patches import Rectangle
 
 
 def plot_colortable(colors, *, ncols=4, sort_colors=True):
@@ -73,21 +74,21 @@ def plot_colortable(colors, *, ncols=4, sort_colors=True):
 
     return fig
 
-#############################################################################
+# %%
 # -----------
 # Base colors
 # -----------
 
 plot_colortable(mcolors.BASE_COLORS, ncols=3, sort_colors=False)
 
-#############################################################################
+# %%
 # ---------------
 # Tableau Palette
 # ---------------
 
 plot_colortable(mcolors.TABLEAU_COLORS, ncols=2, sort_colors=False)
 
-#############################################################################
+# %%
 # ----------
 # CSS Colors
 # ----------
@@ -96,12 +97,14 @@ plot_colortable(mcolors.TABLEAU_COLORS, ncols=2, sort_colors=False)
 plot_colortable(mcolors.CSS4_COLORS)
 plt.show()
 
-#############################################################################
+# %%
 # -----------
 # XKCD Colors
 # -----------
-# XKCD colors are supported, but they produce a large figure, so we skip them
-# for now. You can use the following code if desired::
+# Matplotlib supports colors from the
+# `xkcd color survey <https://xkcd.com/color/rgb/>`_, e.g. ``"xkcd:sky blue"``. Since
+# this contains almost 1000 colors, a figure of this would be very large and is thus
+# omitted here. You can use the following code to generate the overview yourself ::
 #
 #     xkcd_fig = plot_colortable(mcolors.XKCD_COLORS)
 #     xkcd_fig.savefig("XKCD_Colors.png")
@@ -118,3 +121,8 @@ plt.show()
 #    - `matplotlib.figure.Figure.subplots_adjust`
 #    - `matplotlib.axes.Axes.text`
 #    - `matplotlib.patches.Rectangle`
+#
+# .. tags::
+#
+#    styling: color
+#    purpose: reference
