@@ -1,12 +1,13 @@
 """
-Sharing axis limits and views
-=============================
+===========================
+Share axis limits and views
+===========================
 
 It's common to make two or more plots which share an axis, e.g., two subplots
 with time as a common axis.  When you pan and zoom around on one, you want the
 other to move around with you.  To facilitate this, matplotlib Axes support a
 ``sharex`` and ``sharey`` attribute.  When you create a `~.pyplot.subplot` or
-`~.pyplot.axes`, you can pass in a keyword indicating what axes you want to
+`~.pyplot.axes`, you can pass in a keyword indicating what Axes you want to
 share with.
 """
 
@@ -22,3 +23,10 @@ ax2 = plt.subplot(212, sharex=ax1)
 ax2.plot(t, np.sin(4*np.pi*t))
 
 plt.show()
+
+# %%
+# .. tags::
+#
+#    component: axis
+#    plot-type: line
+#    level: beginner
